package com.jz.dmp.config;

import java.io.PrintWriter;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.DisabledException;
import org.springframework.security.config.annotation.method.configuration.EnableGlobalMethodSecurity;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.core.userdetails.UsernameNotFoundException;

import com.alibaba.fastjson.JSONObject;
import com.jz.common.constant.StatuConstant;
import com.jz.common.interceptor.MyFilterSecurityInterceptor;

@Configuration
@EnableGlobalMethodSecurity(prePostEnabled = true)
public class SecurityConfiguration extends WebSecurityConfigurerAdapter {
	@Autowired
	private MyFilterSecurityInterceptor myFilterSecurityInterceptor;

  @Override
  protected void configure(HttpSecurity http) throws Exception {
      http
      .csrf().disable()
      .httpBasic().authenticationEntryPoint((request,response,authException) -> {
			response.setContentType("application/json;charset=utf-8");
			response.setStatus(HttpServletResponse.SC_FORBIDDEN);
			PrintWriter out = response.getWriter();
			Map<String,Object> map = new HashMap<String,Object>();
			map.put("code",StatuConstant.CODE_NOT_SIGNED);
			map.put("message",StatuConstant.MSG_NOT_SIGNED);
			out.write(JSONObject.toJSONString(map));
			out.flush();
			out.close();
		})
      .and()
          .authorizeRequests()
            .antMatchers("/login","/logout").permitAll()
            .anyRequest().authenticated()
            .and()
            .formLogin().loginProcessingUrl("/login")
            .failureHandler((request,response,ex) -> {
				response.setContentType("application/json;charset=utf-8");
				response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
				PrintWriter out = response.getWriter();
				Map<String,Object> map = new HashMap<String,Object>();
				map.put("code",StatuConstant.CODE_ERROR_USERNAMEORPASSWD);
				if (ex instanceof UsernameNotFoundException || ex instanceof BadCredentialsException) {
					map.put("message",StatuConstant.MSG_ERROR_USERNAMEORPASSWD);
				} else if (ex instanceof DisabledException) {
					map.put("message","账户被禁用");
				} else {
					map.put("message","登录失败!");
				}
				out.write(JSONObject.toJSONString(map));
				out.flush();
				out.close();
			})
            //登录成功，返回json
			.successHandler((request,response,authentication) -> {
				Map<String,Object> map = new HashMap<String,Object>();
				map.put("code",StatuConstant.SUCCESS_CODE);
				map.put("message","登录成功");
				map.put("data",authentication);
				response.setContentType("application/json;charset=utf-8");
				PrintWriter out = response.getWriter();
				out.write(JSONObject.toJSONString(map));
				out.flush();
				out.close();
			})
			.and()
			//.addFilter(myFilterSecurityInterceptor)
			//.addFilterAfter(myFilterSecurityInterceptor, afterFilter)
			.exceptionHandling()
			//没有权限返回json
			.accessDeniedHandler((request,response,ex) -> {
				response.setContentType("application/json;charset=utf-8");
				response.setStatus(HttpServletResponse.SC_FORBIDDEN);
				PrintWriter out = response.getWriter();
				Map<String,Object> map = new HashMap<String,Object>();
				map.put("code",StatuConstant.CODE_PERMISSION_NO);
				map.put("message", StatuConstant.MSG_PERMISSION_NO);
				out.write(JSONObject.toJSONString(map));
				out.flush();
				out.close();
			})
			.and()
			.logout()
			//退出成功，返回json
			.logoutSuccessHandler((request,response,authentication) -> {
				Map<String,Object> map = new HashMap<String,Object>();
				map.put("code",StatuConstant.SUCCESS_CODE);
				map.put("message","退出成功");
				map.put("data",authentication);
				response.setContentType("application/json;charset=utf-8");
				PrintWriter out = response.getWriter();
				out.write(JSONObject.toJSONString(map));
				out.flush();
				out.close();
			})
			.permitAll();
  }
  
  

  

}
