package com.jz.dmp.modules.controller;

import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.utils.CommonUtils;
import com.jz.common.utils.FtpUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.net.ftp.FTPClient;
import org.apache.commons.net.ftp.FTPReply;
import org.apache.tomcat.util.http.fileupload.IOUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;

/**
 * @ClassName:
 * @Author: Bellamy
 * @Date: 2021/1/12
 * @Version:
 */
@Controller
@Api(tags = "图片处理")
public class PictureController {

    @Value("${ftp.url}")
    private String ftpUrl;

    @Value("${ftp.port}")
    private Integer port;

    @Value("${ftp.username}")
    private String username;

    @Value("${ftp.password}")
    private String password;

    @PostMapping("/uploadPicture")
    @ApiOperation(value = "图片上传")
    @ResponseBody
    public JsonResult uploadPicture(MultipartFile file, @RequestParam(name = "params",required = false) String params) {
        JsonResult result = new JsonResult();
        if (file.getSize() > 10240000) {
            return JsonResult.error("图片格式太大，不能超过10MB!");
        }
        // 获取图片名称
        String originalFilename = file.getOriginalFilename();
        // 获取图片扩展名
        String extensionName = originalFilename.substring(originalFilename.lastIndexOf("."));
        // 重新命名图片
        String picture = CommonUtils.generatePrimaryKeyId() + extensionName;
        // 上传图片
        try {
            String filePath = "";
            //if (params.equals("datasource")) {
                filePath = "/dmp/datasource";
           // }
            boolean flag = FtpUtil.uploadFile(ftpUrl, port, username, password, "/", filePath, picture, file.getInputStream());
            if (flag) {
                String url = "/dmp/downloadPicture?url=" + filePath + "/" + picture;
                result.setData(url);
                result.setMessage("图片上传成功!");
            } else {
                result.setMessage("图片上传失败!");
                result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            }
        } catch (IOException e) {
            e.printStackTrace();
            result.setMessage("图片上传失败!");
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
        }
        return result;
    }

    @GetMapping("/dmp/downloadPicture")
    @ApiOperation(value = "图片下载")
    public JsonResult downloadPicture(@RequestParam(name = "url") String url, HttpServletResponse response) {

        JsonResult result = new JsonResult();
        FTPClient ftp = new FTPClient();
        String catalog = url.substring(url.lastIndexOf("=")+ 1);
        String remotePath = catalog.substring(0, catalog.lastIndexOf("/") + 1);
        String furl = url.substring(url.lastIndexOf("/") +1);
        String suffix = catalog.substring(catalog.lastIndexOf("."));

        try {
            int reply;
            ftp.connect(ftpUrl, port);
            // 登录
            ftp.login(username, password);
            reply = ftp.getReplyCode();
            if (!FTPReply.isPositiveCompletion(reply)) {
                ftp.disconnect();
            }
            ftp.enterLocalPassiveMode();
            // 到FTP服务器目录
            ftp.changeWorkingDirectory(remotePath);
            InputStream in = ftp.retrieveFileStream(furl);
            ServletOutputStream outputStream = response.getOutputStream();
            int len = 0;
            byte[] buffer = new byte[1024];
            while ((len = in.read(buffer)) != -1) {
                outputStream.write(buffer, 0, len);
            }
//            byte[] bytes = sos.toByteArray();
            response.setContentType("image/jpeg;charset=utf-8");
            //response.setHeader("Content-Disposition", "attachment;filename="+suffix);
            IOUtils.copy(in, outputStream);
            in.close();
            outputStream.close();
            ftp.logout();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            if (ftp.isConnected()) {
                try {
                    ftp.disconnect();
                } catch (Exception ioe) {
                }
            }
        }
        return result;
    }
}
