package com.jz.dmp.modules.service;

import javax.servlet.http.HttpServletRequest;

import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.constant.JsonResult;
import com.jz.common.page.PageInfoResponse;
import com.jz.dmp.modules.controller.DataIntegration.bean.flow.FlowPro;
import com.jz.dmp.modules.controller.bean.DmpDevelopTaskDto;
import com.jz.dmp.modules.controller.bean.DmpDevelopTaskRequest;
import com.jz.dmp.modules.controller.dataOperation.bean.*;
import com.jz.dmp.modules.model.DmpDevelopTask;

/**
 * 任务开发(DmpDevelopTask)表服务接口
 *
 * @author Bellamy
 * @since 2020-12-22 16:37:56
 */
public interface DmpDevelopTaskService {


    JsonResult submitSyncing(DmpDevelopTask task) throws Exception;

    /**
     * 数据运维-数据开发任务列表分页查询
     *
     * @return
     * @author Bellamy
     * @since 2021-01-13
     */
    PageInfoResponse<DataDevTaskListDto> queryDevTaskListPage(DataDevTaskListReq req) throws Exception;

    /**
     * 数据运维-执行任务
     *
     * @return
     * @author Bellamy
     */
    JsonResult runTaskByTaskId(String taskId) throws Exception;

    /**
     * 数据运维-数据开发实例列表分页查询
     *
     * @return
     * @author Bellamy
     * @since 2021-01-14
     */
    PageInfoResponse<DataDevExamplesListDto> queryDevExamplesListPage(DataDevExamplesListReq req) throws Exception;

    /**
     * 条件分頁查询所有任务开发
     *
     * @param dmpDevelopTaskRequest
     * @param httpRequest
     * @return
     * @throws Exception
     */
    public com.jz.common.bean.PageInfoResponse<DmpDevelopTaskDto> findListWithPage(DmpDevelopTaskRequest dmpDevelopTaskRequest, HttpServletRequest httpRequest) throws Exception;

    /**
     * @param @param  treeId
     * @param @return
     * @param @throws Exception    参数
     * @return String    返回类型
     * @throws
     * @Title: getConfigFileNameNotSuffix4Published
     * @Description: TODO(根据treeId取得最新版提交的同步脚本文件名 （ 不含后缀 ） 及版本信息)
     */
    public String getConfigFileNameNotSuffix4Published(Long treeId) throws Exception;

    /**
     * 新增开发任务
     *
     * @param dmpDevelopTask
     * @param httpRequest
     * @return
     * @throws Exception
     */
    public BaseBeanResponse<DmpDevelopTask> add(DmpDevelopTask dmpDevelopTask, HttpServletRequest httpRequest) throws Exception;

    /**
     * 树ID查询任务开发
     *
     * @param treeId
     * @param httpRequest
     * @return
     * @throws Exception
     */
    public BaseBeanResponse<DmpDevelopTaskDto> findByTreeId(Integer treeId, HttpServletRequest httpRequest) throws Exception;

    /**
     * 修改任务开发
     *
     * @param dmpDevelopTask
     * @param httpRequest
     * @return
     * @throws Exception
     */
    public BaseBeanResponse<DmpDevelopTask> edit(DmpDevelopTask dmpDevelopTask, HttpServletRequest httpRequest) throws Exception;


    /**
     * @param @param  treeId
     * @param @param  httpRequest
     * @param @return
     * @param @throws Exception    参数
     * @return BaseResponse    返回类型
     * @throws
     * @Title: flowSubmit
     * @Description: TODO(任务流程发布到azkaban)
     */
    public BaseResponse flowSubmit(Long treeId, HttpServletRequest httpRequest) throws Exception;

    /**
     * @param @param  treeId
     * @param @param  httpRequest
     * @param @return
     * @param @throws Exception    参数
     * @return BaseBeanResponse    返回类型
     * @throws
     * @Title: taskAzkabanRun
     * @Description: TODO(运行任务)
     */
    public BaseBeanResponse<Integer> taskAzkabanRun(Long treeId, HttpServletRequest httpRequest) throws Exception;

    /**
     * @param @param  treeId
     * @param @param  httpRequest
     * @param @return 参数
     * @return BaseBeanResponse<String>    返回类型
     * @throws
     * @Title: taskAzkabanStop
     * @Description: TODO(停止任务)
     */
    public BaseBeanResponse<String> taskAzkabanStop(Long treeId, HttpServletRequest httpRequest) throws Exception;

    /**
     * @param @param  treeId
     * @param @param  httpRequest
     * @param @return
     * @param @throws Exception    参数
     * @return BaseResponse    返回类型
     * @throws
     * @Title: taskPublish
     * @Description: TODO(SHELL / SQL发布接口)
     */
    public BaseResponse taskPublish(Long treeId, HttpServletRequest httpRequest) throws Exception;

    /**
     * @param @param  treeId
     * @param @param  httpRequest
     * @param @return
     * @param @throws Exception    参数
     * @return BaseResponse    返回类型
     * @throws
     * @Title: softDeleteByTreeId
     * @Description: TODO(软删除任务)
     */
    public BaseResponse softDeleteByTreeId(Integer treeId, HttpServletRequest httpRequest) throws Exception;

    /**
     * @param @param  syncTaskTreeId
     * @param @return
     * @param @throws Exception    参数
     * @return String    返回类型
     * @throws
     * @Title: getExecXmlFileName
     * @Description: TODO(根据任务treeId获取xmlFileName)
     */
    public String getExecXmlFileName(Long syncTaskTreeId) throws Exception;

    /**
     * 获取执行实例的日志详情
     *
     * @return
     * @author Bellamy
     * @since 2021-02-03
     */
    JsonResult queryExamplesLogByExecId(String execId, String projectId) throws Exception;

    /**
     * 运维大屏--获取任务状态
     *
     * @return
     * @author Bellamy
     * @since 2021-02-22
     */
    JsonResult getTaskStatus(String projectId) throws Exception;

    /**
     * 设置SLA
     *
     * @return
     * @author Bellamy
     * @since 2021-02-03
     */
    JsonResult setSla(SetSlaReq req) throws Exception;

    /**
     * 运维大屏--任务完成情况
     *
     * @return
     * @author Bellamy
     * @since 2021-03-08
     */
    JsonResult getTaskStatusByHours(String projectId, String taskStatus) throws Exception;

    /**
     * 获取 SLA
     *
     * @return
     * @author Bellamy
     * @since 2021-03-08
     */
    JsonResult getSlaInfo(String scheduleId, String projectId) throws Exception;

    /**
     * 获取 flowId/任务名称
     *
     * @return
     * @author Bellamy
     * @since 2021-03-08
     */
    JsonResult getTaskFlowId(String projectId) throws Exception;
}