package com.jz.dmp.modules.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import com.jz.dmp.modules.dao.DmpWorkFlowSubmitDetailsDao;
import com.jz.dmp.modules.model.DmpWorkFlowSubmitDetails;
import com.jz.dmp.modules.service.DmpWorkFlowSubmitDetailsService;

@Service
public class DmpWorkFlowSubmitDetailsServiceImpl implements DmpWorkFlowSubmitDetailsService {

    protected final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private DmpWorkFlowSubmitDetailsDao dao;

    /**
     * 获取项目里某个流的节点的最新数据
     *
     * @param map
     * @return
     */
    @Override
    public List<DmpWorkFlowSubmitDetails> getLatestUnderFlowByNodeName(Map map) {
        return dao.getLatestUnderFlowByNodeName(map);
    }

    @Override
    public int getLatestVersionByProjectIdFlowNameAndNodeName(Map map){
        Integer result = dao.getLatestVersionByProjectIdFlowNameAndNodeName(map);
        if (result == null){
            return 0;
        }
        return  result;
    }

    public void  deleteDmpWorkFlowSubmitDetailsByProjectIdFlowNameAndNodeName(Map map){
        dao.deleteDmpWorkFlowSubmitDetailsByProjectIdFlowNameAndNodeName(map);
    }

    /**
     * 获取某个项目下除了当前流下的所有job名称  判断是否重复
     *
     * @param queryMap projectId:项目id
     *                 flowName：流程名
     * @return
     */
    @Override
    public Map<String, Integer> getAllJobNamesByProjectIdBesidesFlowName(Map queryMap) {
        List<DmpWorkFlowSubmitDetails> list =  dao.getAllJobNamesByProjectIdBesidesFlowName(queryMap);
        if (CollectionUtils.isEmpty(list)){
            return new HashMap<>();
        }

        Map<String,Integer> result = new HashMap<>();

        for (DmpWorkFlowSubmitDetails dmpWorkFlowSubmitDetails : list){
            result.put(dmpWorkFlowSubmitDetails.getNodeName(), 1);
        }
        return  result;
    }

    @Override
    public List<DmpWorkFlowSubmitDetails> findNodeHistory(DmpWorkFlowSubmitDetails body) {
        return dao.findNodeHistory(body);
    }

    @Override
    public DmpWorkFlowSubmitDetails getMaxVersionByScheduleProjectIdAndFlowNameNodeName(Map map) {
        return dao.getMaxVersionByScheduleProjectIdAndFlowNameNodeName(map);
    }

    @Override
    @Transactional(readOnly = false)
    public void deleteByFlow(DmpWorkFlowSubmitDetails detail) {
        dao.deleteByFlow(detail);
    }

    @Override
    public boolean checkNodeNameExists(String nodeName) {
        return dao.countByNodeName(nodeName) >= 1;
    }
}
